//
// Created by martin on 11.02.22.
//

#ifndef ANIMTESTBED_ANIMGRAPHEDITOR_H
#define ANIMTESTBED_ANIMGRAPHEDITOR_H

namespace ax::NodeEditor {
struct EditorContext;
}  // namespace ax::NodeEditor

struct SkinnedMesh;
struct AnimGraphBlendTree;
struct SyncTrack;

constexpr int cMaxSocketsPerNode = 500;
constexpr int cMaxNodesPerGraph = 1000;

inline int GenerateInputAttributeId(int node_id, int input_index) {
  return ((input_index + 1) << 14) + node_id;
}

inline void
SplitInputAttributeId(int attribute_id, int* node_id, int* input_index) {
  *node_id = attribute_id & ((1 << 14) - 1);
  *input_index = (attribute_id >> 14) - 1;
}

inline int GenerateOutputAttributeId(int node_id, int output_index) {
  return ((output_index + 1) << 23) + node_id;
}

inline void
SplitOutputAttributeId(int attribute_id, int* node_id, int* output_index) {
  *node_id = attribute_id & ((1 << 14) - 1);
  *output_index = (attribute_id >> 23) - 1;
}

inline int NodeIndexAndSocketIndexToInputPinId(
    int node_index,
    int input_socket_index) {
  return node_index * cMaxNodesPerGraph + input_socket_index;
}

inline int NodeIndexAndSocketIndexToOutputPinId(
    int node_index,
    int output_socket_index) {
  return node_index * cMaxNodesPerGraph + cMaxSocketsPerNode
         + output_socket_index;
}

inline void InputPinIdToNodeIndexAndSocketIndex(
    unsigned long input_pin_id,
    int* node_index,
    int* socket_index) {
  *socket_index = static_cast<int>(input_pin_id) % cMaxNodesPerGraph;
  *node_index =
      (static_cast<int>(input_pin_id) - *socket_index) / cMaxNodesPerGraph;
}

inline void OutputPinIdToNodeIndexAndSocketIndex(
    unsigned long output_pin_id,
    int* node_index,
    int* socket_index) {
  *socket_index =
      ((static_cast<int>(output_pin_id) - cMaxSocketsPerNode)
       % cMaxNodesPerGraph);
  *node_index =
      (static_cast<int>(output_pin_id) - *socket_index) / cMaxNodesPerGraph;
}

inline bool IsPinInput(unsigned long pin_id) {
  return ((pin_id % cMaxNodesPerGraph) >= cMaxSocketsPerNode);
}

inline bool IsPinOutput(unsigned long pin_id) { return !IsPinInput(pin_id); }

void SyncTrackEditor(SyncTrack* sync_track);

void SkinnedMeshWidget(SkinnedMesh* skinned_mesh);

void AnimGraphEditorClear();

void AnimGraphEditorUpdate(ax::NodeEditor::EditorContext* context);

void AnimGraphEditorGetRuntimeBlendTree(AnimGraphBlendTree& anim_graph);

#endif  //ANIMTESTBED_ANIMGRAPHEDITOR_H
